@@ -1,13 +1,18 @@
-hscat = function(formula, data, breaks, pch = 3, cex = .6, ...) {
+hscat = function(formula, data, breaks, pch = 3, cex = .6, mirror = FALSE, 
+		variogram.alpha = 0, ...) {
 	stopifnot(!missing(breaks))
-	x = variogram(formula, data, cloud = TRUE, ...)
-	.BigInt = attr(x, ".BigInt")
-	x$left = x$np%%.BigInt + 1
-	x$right = x$np%/%.BigInt + 1
+	x = variogram(formula, data, cloud = TRUE, cutoff = max(breaks), 
+		alpha = variogram.alpha, ...)
+	x = as.data.frame(x)
 	x$class = cut(x$dist, breaks = breaks)
 	y = model.frame(formula, data)[[1]]
 	x$xx = y[x$left]
 	x$yy = y[x$right]
+	if (mirror) 
+		x = data.frame(
+			xx = c(x$yy, y[x$left]),
+			yy = c(x$xx, y[x$right]),
+			class = c(x$class, x$class))
 	lab = as.character(formula)[2]
 	panel = function(x,y,subscripts, ...) {
 		xr = c(min(x),max(x))
