@@ -28,8 +28,9 @@
 
 #include 	"matrix.h"
 
-
+/*
 static	char	rcsid[] = "$Id: memory.c,v 1.1.1.1 2003-06-23 18:31:37 cees Exp $";
+*/
 
 /* m_get -- gets an mxn matrix (in MAT form) by dynamic memory allocation */
 MAT	*m_get(m,n)
@@ -283,7 +284,7 @@ int	new_m, new_n;
 		      new_m*sizeof(Real *));
       }
 
-      A->me = RENEW(A->me,new_m,Real *);
+      RENEW(A->me,new_m,Real *);
       if ( ! A->me )
 	error(E_MEM,"m_resize");
    }
@@ -299,7 +300,7 @@ int	new_m, new_n;
 		      new_size*sizeof(Real));
       }
 
-      A->base = RENEW(A->base,new_size,Real);
+      RENEW(A->base,new_size,Real);
       if ( ! A->base )
 	error(E_MEM,"m_resize");
       A->max_size = new_size;
@@ -417,7 +418,7 @@ int	new_size;
 	 mem_bytes(TYPE_PERM,px->max_size*sizeof(u_int),
 		      new_size*sizeof(u_int));
       }
-      px->pe = RENEW(px->pe,new_size,u_int);
+      RENEW(px->pe,new_size,u_int);
       if ( ! px->pe )
 	error(E_MEM,"px_resize");
       px->max_size = new_size;
@@ -462,7 +463,7 @@ int	new_dim;
 			 new_dim*sizeof(Real));
       }
 
-      x->ve = RENEW(x->ve,new_dim,Real);
+      RENEW(x->ve,new_dim,Real);
       if ( ! x->ve )
 	error(E_MEM,"v_resize");
       x->max_dim = new_dim;
@@ -505,7 +506,7 @@ int v_get_vars(int dim,...)
    VEC **par;
    
    va_start(ap, dim);
-   while (par = va_arg(ap,VEC **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,VEC **))) {   /* NULL ends the list*/
       *par = v_get(dim);
       i++;
    } 
@@ -522,7 +523,7 @@ int iv_get_vars(int dim,...)
    IVEC **par;
    
    va_start(ap, dim);
-   while (par = va_arg(ap,IVEC **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,IVEC **))) {   /* NULL ends the list*/
       *par = iv_get(dim);
       i++;
    } 
@@ -538,7 +539,7 @@ int m_get_vars(int m,int n,...)
    MAT **par;
    
    va_start(ap, n);
-   while (par = va_arg(ap,MAT **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,MAT **))) {   /* NULL ends the list*/
       *par = m_get(m,n);
       i++;
    } 
@@ -554,7 +555,7 @@ int px_get_vars(int dim,...)
    PERM **par;
    
    va_start(ap, dim);
-   while (par = va_arg(ap,PERM **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,PERM **))) {   /* NULL ends the list*/
       *par = px_get(dim);
       i++;
    } 
@@ -586,7 +587,7 @@ int v_resize_vars(int new_dim,...)
    VEC **par;
    
    va_start(ap, new_dim);
-   while (par = va_arg(ap,VEC **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,VEC **))) {   /* NULL ends the list*/
       *par = v_resize(*par,new_dim);
       i++;
    } 
@@ -604,7 +605,7 @@ int iv_resize_vars(int new_dim,...)
    IVEC **par;
    
    va_start(ap, new_dim);
-   while (par = va_arg(ap,IVEC **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,IVEC **))) {   /* NULL ends the list*/
       *par = iv_resize(*par,new_dim);
       i++;
    } 
@@ -620,7 +621,7 @@ int m_resize_vars(int m,int n,...)
    MAT **par;
    
    va_start(ap, n);
-   while (par = va_arg(ap,MAT **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,MAT **))) {   /* NULL ends the list*/
       *par = m_resize(*par,m,n);
       i++;
    } 
@@ -637,7 +638,7 @@ int px_resize_vars(int new_dim,...)
    PERM **par;
    
    va_start(ap, new_dim);
-   while (par = va_arg(ap,PERM **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,PERM **))) {   /* NULL ends the list*/
       *par = px_resize(*par,new_dim);
       i++;
    } 
@@ -668,7 +669,7 @@ int v_free_vars(VEC **pv,...)
    v_free(*pv);
    *pv = VNULL;
    va_start(ap, pv);
-   while (par = va_arg(ap,VEC **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,VEC **))) {   /* NULL ends the list*/
       v_free(*par); 
       *par = VNULL;
       i++;
@@ -688,7 +689,7 @@ int iv_free_vars(IVEC **ipv,...)
    iv_free(*ipv);
    *ipv = IVNULL;
    va_start(ap, ipv);
-   while (par = va_arg(ap,IVEC **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,IVEC **))) {   /* NULL ends the list*/
       iv_free(*par); 
       *par = IVNULL;
       i++;
@@ -708,7 +709,7 @@ int px_free_vars(PERM **vpx,...)
    px_free(*vpx);
    *vpx = PNULL;
    va_start(ap, vpx);
-   while (par = va_arg(ap,PERM **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,PERM **))) {   /* NULL ends the list*/
       px_free(*par); 
       *par = PNULL;
       i++;
@@ -727,7 +728,7 @@ int m_free_vars(MAT **va,...)
    m_free(*va);
    *va = MNULL;
    va_start(ap, va);
-   while (par = va_arg(ap,MAT **)) {   /* NULL ends the list*/
+   while ((par = va_arg(ap,MAT **))) {   /* NULL ends the list*/
       m_free(*par); 
       *par = MNULL;
       i++;
